#!/usr/bin/python3

import nsysstats

class OpenMPEventSummary(nsysstats.StatsReport):

    display_name = 'DEPRECATED - Use openmp_sum instead'
    usage = '{SCRIPT} -- {{DISPLAY_NAME}}'
    should_display = False

    query_stub = """
WITH
    summary AS (
        {OPEN_MP_UNION}
    ),
    totals AS (
        SELECT sum(total) AS total
        FROM summary
    )
SELECT
    round(summary.total * 100.0 / (SELECT total FROM totals), 1) AS "Time:ratio_%",
    summary.total AS "Total Time:dur_ns",
    summary.num AS "Count",
    round(summary.avg, 1) AS "Avg:dur_ns",
    round(summary.med, 1) AS "Med:dur_ns",
    summary.min AS "Min:dur_ns",
    summary.max AS "Max:dur_ns",
    round(summary.stddev, 1) AS "StdDev:dur_ns",
    ids.value AS "Name"
FROM
    summary
LEFT JOIN
    StringIds AS ids
    ON ids.id == summary.nameId
ORDER BY 2 DESC
;
"""

    query_omp = """
        SELECT
            nameId AS nameId,
            count(*) AS num,
            sum(end - start) AS total,
            avg(end - start) AS avg,
            median(end - start) AS med,
            min(end - start) AS min,
            max(end - start) AS max,
            stdev(end - start) AS stddev
        FROM {TABLE}
        GROUP BY 1
"""

    query_union = """
        UNION ALL
"""

    def setup(self):
        err = super().setup()
        if err != None:
            return err

        omp_tables = self.search_tables(r'^OPENMP_EVENT_KIND_.+$')
        if len(omp_tables) == 0:
            return "{DBFILE} does not contain OpenMP event data."

        omp_queries = list(self.query_omp.format(TABLE=t) for t in omp_tables)
        self.query = self.query_stub.format(OPEN_MP_UNION = self.query_union.join(omp_queries))

if __name__ == "__main__":
    OpenMPEventSummary.Main()
